@@ -1,16 +1,16 @@
 from typing import Any
 from typing import Optional
 
-from .protocol import MixedStackedModel
-from .protocol import register_ml_module
+from ..register import register_ml_module
+from ..protocols.ml import MixedStackedModel
 
 
 @register_ml_module("transformer")
 class Transformer(MixedStackedModel):
     def __init__(
         self,
-        in_dim: int,
-        out_dim: int,
+        input_dim: int,
+        output_dim: int,
         num_history: int,
         latent_dim: int = 256,
         *,
@@ -24,8 +24,8 @@ class Transformer(MixedStackedModel):
         attention_kwargs.setdefault("bias", False)
         attention_kwargs.setdefault("num_heads", 8)
         super().__init__(
-            in_dim,
-            out_dim,
+            input_dim,
+            output_dim,
             num_history,
             latent_dim,
             token_mixing_type="attention",
@@ -36,6 +36,7 @@ class Transformer(MixedStackedModel):
             feedforward_dim_ratio=feedforward_dim_ratio,
             use_head_token=use_head_token,
             use_positional_encoding=True,
+            is_vision_positional_encoding=False,
         )
 
 
